.twitter-typeahead {
    width: 100%;
    /*font-size: 1rem;*/
}

.twitter-typeahead .tt-input {
    width: 100% !important;
    box-sizing: border-box;
}

.twitter-typeahead .tt-hint {
    color: #a0a09c;
    width: 100% !important;
}

.twitter-typeahead .tt-menu {
    right: 0;
    background: #FFF;
    text-align: left;
    box-shadow: 0 15px 15px rgba(0, 0, 0, 0.25);
    max-height: 8rem;
    overflow-y: scroll;
}

.twitter-typeahead .tt-suggestion {
    padding: 0.5rem;
    cursor: pointer;
    position: relative;
    color: #1f1f1e;
    border-top: 1px solid #e1e1e1;
}

.twitter-typeahead .tt-suggestion .flag {
    margin: 0 0.75rem;
}

.twitter-typeahead .tt-suggestion.tt-cursor,
.twitter-typeahead .tt-suggestion:hover {
    background: #a3333d;
    color: #e1e1e1;
}

.twitter-typeahead .tt-suggestion.tt-cursor:before,
.twitter-typeahead .tt-suggestion:hover:before,
.twitter-typeahead .tt-suggestion.tt-cursor:after,
.twitter-typeahead .tt-suggestion:hover:after {
    color: #FFF;
}

.twitter-typeahead .tt-nothing-found {
    padding: 0.5rem;
    font-style: italic;
    color: #1f1f1e;
}

form .chips {
    font-size: 0;
}

form .chips .chip {
    position: relative;
    display: inline-block;
    background: #20a4f3;
    color: #FFF;
    font-weight: bold;
    padding: 0.5rem;
    border-radius: 2px;
    margin: 0 0.25rem 0.25rem 0;
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
    -webkit-transform: scaleX(1);
    -moz-transform: scaleX(1);
    -ms-transform: scaleX(1);
    -o-transform: scaleX(1);
    transform: scaleX(1);
    -webkit-transform-origin: 0 50%;
    -moz-transform-origin: 0 50%;
    -ms-transform-origin: 0 50%;
    -o-transform-origin: 0 50%;
    transform-origin: 0 50%;
}

form .chips .chip a {
    color: #FFFFFF;
    text-decoration: none;
}

form .chips .chip.minimized {
    pointer-events: none;
    -webkit-transform: scaleX(0);
    -moz-transform: scaleX(0);
    -ms-transform: scaleX(0);
    -o-transform: scaleX(0);
    transform: scaleX(0);
}

form .chips .chip:not(.read-only):after {
    -webkit-transition: all 0.2s ease-in-out;
    -moz-transition: all 0.2s ease-in-out;
    -ms-transition: all 0.2s ease-in-out;
    -o-transition: all 0.2s ease-in-out;
    transition: all 0.2s ease-in-out;
    opacity: 0;
    background: #a3333d;
    color: #FFF;
    content: 'Delete';
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    text-align: center;
    font-size: 0.8rem;
    line-height: 2rem;
    cursor: pointer;
}

form .chips .chip:not(.read-only):hover:after {
    opacity: 1;
}

form .chips .chip,
form .chips .control {
    font-size: 0.9rem;
    line-height: 0.9rem;
    vertical-align: top;
}

.form-row.form-row-no-overflows {
    overflow: visible;
}

.form-row.form-row-no-overflows::after {
    content: '';
    display: block;
    clear: both;
}

.form-row-no-overflows .related-widget-wrapper {
    overflow: visible;
}
